@@ -31,16 +31,6 @@ namespace
 Q_LOGGING_CATEGORY(category, "kf.kio.urifilters.shorturi", QtWarningMsg)
 }
 
-/**
- * IMPORTANT: If you change anything here, make sure you run the kurifiltertest
- * regression test (this should be included as part of "make test").
- *
- * If you add anything, make sure to extend kurifiltertest to make sure it is
- * covered.
- */
-
-typedef QMap<QString, QString> EntryMap;
-
 static bool isPotentialShortURL(const QString &cmd)
 {
     // Host names and IPv4 address...
@@ -62,6 +52,10 @@ static QString removeArgs(const QString &_cmd)
 {
     QString cmd(_cmd);
 
+    if (cmd.isEmpty()) {
+        return cmd;
+    }
+
     if (cmd[0] != QLatin1Char('\'') && cmd[0] != QLatin1Char('"')) {
         // Remove command-line options (look for first non-escaped space)
         int spacePos = 0;
@@ -81,15 +75,15 @@ static QString removeArgs(const QString &_cmd)
 
 static bool isKnownProtocol(const QString &protocol)
 {
-    if (KProtocolInfo::isKnownProtocol(protocol) || protocol == QLatin1String("mailto")) {
+    if (KProtocolInfo::isKnownProtocol(protocol, false) || protocol == QLatin1String("mailto")) {
         return true;
     }
     const KService::Ptr service = KApplicationTrader::preferredService(QLatin1String("x-scheme-handler/") + protocol);
     return service;
 }
 
-KShortUriFilter::KShortUriFilter(QObject *parent, const QVariantList & /*args*/)
-    : KUriFilterPlugin(QStringLiteral("kshorturifilter"), parent)
+KShortUriFilter::KShortUriFilter(QObject *parent, const KPluginMetaData &data)
+    : KUriFilterPlugin(parent, data)
 {
     QDBusConnection::sessionBus()
         .connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"), this, SLOT(configure()));
@@ -478,30 +472,17 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     return false;
 }
 
-// TODO KF6: unused, remove
-KCModule *KShortUriFilter::configModule(QWidget *, const char *) const
-{
-    return nullptr; // new KShortUriOptions( parent, name );
-}
-
-// TODO KF6: unused, remove
-QString KShortUriFilter::configName() const
-{
-    //    return i18n("&ShortURLs"); we don't have a configModule so no need for a configName that confuses translators
-    return KUriFilterPlugin::configName();
-}
-
 void KShortUriFilter::configure()
 {
     KConfig config(objectName() + QStringLiteral("rc"), KConfig::NoGlobals);
-    KConfigGroup cg(config.group(""));
+    KConfigGroup cg(config.group(QString()));
 
     m_strDefaultUrlScheme = cg.readEntry("DefaultProtocol", QStringLiteral("https://"));
-    const EntryMap patterns = config.entryMap(QStringLiteral("Pattern"));
-    const EntryMap protocols = config.entryMap(QStringLiteral("Protocol"));
-    KConfigGroup typeGroup(&config, "Type");
+    const QMap<QString, QString> patterns = config.entryMap(QStringLiteral("Pattern"));
+    const QMap<QString, QString> protocols = config.entryMap(QStringLiteral("Protocol"));
+    KConfigGroup typeGroup(&config, QStringLiteral("Type"));
 
-    for (EntryMap::ConstIterator it = patterns.begin(); it != patterns.end(); ++it) {
+    for (auto it = patterns.begin(); it != patterns.end(); ++it) {
         QString protocol = protocols[it.key()];
         if (!protocol.isEmpty()) {
             int type = typeGroup.readEntry(it.key(), -1);
@@ -517,3 +498,5 @@ void KShortUriFilter::configure()
 K_PLUGIN_CLASS_WITH_JSON(KShortUriFilter, "kshorturifilter.json")
 
 #include "kshorturifilter.moc"
+
+#include "moc_kshorturifilter.cpp"
