@@ -31,6 +31,7 @@
 #include <KService>
 #include <KUrlMimeData>
 
+#include <QDBusConnection>
 #include <QDBusPendingCall>
 #include <QDropEvent>
 #include <QFileInfo>
@@ -79,8 +80,8 @@ public:
         , m_mimeData(dropEvent->mimeData()) // Extract everything from the dropevent, since it will be deleted before the job starts
         , m_urls(KUrlMimeData::urlsFromMimeData(m_mimeData, KUrlMimeData::PreferLocalUrls, &m_metaData))
         , m_dropAction(dropEvent->dropAction())
-        , m_relativePos(dropEvent->pos())
-        , m_keyboardModifiers(dropEvent->keyboardModifiers())
+        , m_relativePos(dropEvent->position().toPoint())
+        , m_keyboardModifiers(dropEvent->modifiers())
         , m_hasArkFormat(m_mimeData->hasFormat(s_applicationSlashXDashKDEDashArkDashDnDExtractDashService)
                          && m_mimeData->hasFormat(s_applicationSlashXDashKDEDashArkDashDnDExtractDashPath))
         , m_destUrl(destUrl)
@@ -341,7 +342,7 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
 
 void DropJobPrivate::addPluginActions(KIO::DropMenu *popup, const KFileItemListProperties &itemProps)
 {
-    const QVector<KPluginMetaData> plugin_offers = KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kio_dnd"));
+    const QList<KPluginMetaData> plugin_offers = KPluginMetaData::findPlugins(QStringLiteral("kf6/kio_dnd"));
     for (const KPluginMetaData &data : plugin_offers) {
         if (auto plugin = KPluginFactory::instantiatePlugin<KIO::DndPopupMenuPlugin>(data).plugin) {
             const auto actions = plugin->setup(itemProps, m_destUrl);
