@@ -14,6 +14,8 @@
 
 #include "kiowidgets_export.h"
 
+#include <memory>
+
 class QDateTime;
 
 namespace KIO
@@ -45,7 +47,7 @@ public:
      * Interface for the gui handling of FileUndoManager.
      * This includes three events currently:
      * - error when undoing a job
-     * - confirm deletion before undoing a copy job
+     * - (until KF 5.78) confirm deletion before undoing a copy job
      * - confirm deletion when the copied file has been modified afterwards
      *
      * By default UiInterface shows message boxes in all three cases;
@@ -81,12 +83,6 @@ public:
          */
         virtual void jobError(KIO::Job *job);
 
-        /**
-         * Called when we are about to remove those files.
-         * Return true if we should proceed with deleting them.
-         */
-        virtual bool confirmDeletion(const QList<QUrl> &files);
-
         /**
          * Called when dest was modified since it was copied from src.
          * Note that this is called after confirmDeletion.
@@ -94,6 +90,8 @@ public:
          */
         virtual bool copiedFileWasModified(const QUrl &src, const QUrl &dest, const QDateTime &srcTime, const QDateTime &destTime);
 
+        // TODO KF6 replace hook with virtual AskUserActionInterface* askUserActionInterface(); // (does not take ownership)
+        enum { HookGetAskUserActionInterface = 1 };
         /**
          * \internal, for future extensions
          */
@@ -119,14 +117,18 @@ public:
 
     /**
      * The type of job.
-     *
-     * Put: @since 4.7, represents the creation of a file from data in memory.
-     *                Used when pasting data from clipboard or drag-n-drop.
-     * Mkpath: @since 5.4, represents a KIO::mkpath() job.
-     * BatchRename: @since 5.42, represents a KIO::batchRename() job. Used when
-     *              renaming multiple files.
      */
-    enum CommandType { Copy, Move, Rename, Link, Mkdir, Trash, Put, Mkpath, BatchRename };
+    enum CommandType {
+        Copy,
+        Move,
+        Rename,
+        Link,
+        Mkdir,
+        Trash,
+        Put, ///< Represents the creation of a file from data in memory. Used when pasting data from clipboard or drag-n-drop. @since 4.7
+        Mkpath, ///< Represents a KIO::mkpath() job. @since 5.4
+        BatchRename ///< Represents a KIO::batchRename() job. Used when renaming multiple files. @since 5.42
+    };
 
     /**
      * Record this job while it's happening and add a command for it so that the user can undo it.
@@ -146,8 +148,11 @@ public:
 
     /**
      * @return true if undo is possible. Usually used for enabling/disabling the undo action.
+     *
+     * @since 5.79
      */
-    bool undoAvailable() const;
+    bool isUndoAvailable() const;
+
     /**
      * @return the current text for the undo action.
      */
@@ -171,10 +176,10 @@ public Q_SLOTS:
      * This operation is asynchronous.
      * undoJobFinished will be emitted once the undo is complete.
      */
-    void undo();
+    void undo(); // TODO pass QWindow*, for askUserInterface->askUserDelete and error handling etc.
 
 Q_SIGNALS:
-    /// Emitted when the value of undoAvailable() changes
+    /// Emitted when the value of isUndoAvailable() changes
     void undoAvailable(bool avail);
 
     /// Emitted when the value of undoText() changes
@@ -187,7 +192,6 @@ Q_SIGNALS:
      * Emitted when a job recording has been started by FileUndoManager::recordJob()
      * or FileUndoManager::recordCopyJob(). After the job recording has been finished,
      * the signal jobRecordingFinished() will be emitted.
-     * @since 4.2
      */
     void jobRecordingStarted(CommandType op);
 
@@ -195,20 +199,19 @@ Q_SIGNALS:
      * Emitted when a job that has been recorded by FileUndoManager::recordJob()
      * or FileUndoManager::recordCopyJob has been finished. The command
      * is now available for an undo-operation.
-     * @since 4.2
      */
-    void jobRecordingFinished(CommandType op);
+    void jobRecordingFinished(FileUndoManager::CommandType op);
 
 private:
-    FileUndoManager();
-    virtual ~FileUndoManager();
+    KIOWIDGETS_NO_EXPORT FileUndoManager();
+    KIOWIDGETS_NO_EXPORT ~FileUndoManager() override;
     friend class FileUndoManagerSingleton;
 
     friend class UndoJob;
     friend class CommandRecorder;
 
     friend class FileUndoManagerPrivate;
-    FileUndoManagerPrivate *d;
+    std::unique_ptr<FileUndoManagerPrivate> d;
 };
 
 } // namespace
